==> raqdevil-0.9.6.tar.gz: raqdevil-0.9.6/cce-am-1.0/activemonitor/base-snmp-am/am_snmp.pl <==
#!/usr/bin/perl -I(prefix)/raqdevil/perl
# test snmp state

use strict;
use warnings;
use AM::Util;
use CCE;

my $cce = new CCE;
$cce->connectuds();

my %am_states = am_get_statecodes();

my ($sysoid) = $cce->findx('System');
my ($ok, $object) = $cce->get($sysoid, 'Snmp');
if (!$ok) {
    $cce->bye('FAIL');
    exit $am_states{AM_STATE_NOINFO};

}

# return value of snmpwalk indicates if it successfully found the sysName
# property
my $fail = system("/usr/bin/snmpwalk localhost $object->{readCommunity} system.sysName >/dev/null 2>&1");
if ($fail) {
    # can't directly call "system" since snmpd doesn't close stdin
    # and as a result, swatch would keep waiting forever
    # my_system handles the closing of stdin/stdout and so it all works
    AM::Util::my_system('(prefix)/etc/rc.d/snmpd restart >/dev/null 2>&1');
    sleep 3;
    $fail = system("/usr/bin/snmpwalk localhost $object->{readCommunity} system.sysName >/dev/null 2>&1");
    if ($fail) {
	print $ENV{redMsg};
	exit $am_states{AM_STATE_RED};
    }
}

print $ENV{greenMsg};
exit $am_states{AM_STATE_GREEN};

# Copyright (c) 2003 Sun Microsystems, Inc. All  Rights Reserved.
# 
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions are met:
# 
# -Redistribution of source code must retain the above copyright notice, 
# this list of conditions and the following disclaimer.
# 
# -Redistribution in binary form must reproduce the above copyright notice, 
# this list of conditions and the following disclaimer in the documentation  
# and/or other materials provided with the distribution.
# 
# Neither the name of Sun Microsystems, Inc. or the names of contributors may 
# be used to endorse or promote products derived from this software without 
# specific prior written permission.
# 
# This software is provided "AS IS," without a warranty of any kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED. SUN MICROSYSTEMS, INC. ("SUN") AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
# 
# You acknowledge that  this software is not designed or intended for use in the design, construction, operation or maintenance of any nuclear facility.

==> raqdevil-1.0.tar.gz: raqdevil-1.0/cce-am-1.0/activemonitor/base-snmp-am/am_snmp.pl <==
#!/usr/bin/perl -I(prefix)/raqdevil/perl
# test snmp state

use strict;
use warnings;
use AM::Util;
use CCE;

my $cce = new CCE;
$cce->connectuds();

my %am_states = am_get_statecodes();

my ($sysoid) = $cce->findx('System');
my ($ok, $object) = $cce->get($sysoid, 'Snmp');
if (!$ok) {
    $cce->bye('FAIL');
    exit $am_states{AM_STATE_NOINFO};

}

# return value of snmpwalk indicates if it successfully found the sysName
# property
my $fail = system("(prefix)/bin/snmpwalk -Os -c $object->{readCommunity} -v 1 localhost system.sysName >/dev/null 2>&1");
if ($fail) {
    # can't directly call "system" since snmpd doesn't close stdin
    # and as a result, swatch would keep waiting forever
    # my_system handles the closing of stdin/stdout and so it all works
    AM::Util::my_system('(prefix)/etc/rc.d/snmpd restart >/dev/null 2>&1');
    sleep 3;
    $fail = system("(prefix)/bin/snmpwalk -Os -c $object->{readCommunity} -v 1 localhost system.sysName >/dev/null 2>&1");
    if ($fail) {
	print $ENV{redMsg};
	exit $am_states{AM_STATE_RED};
    }
}

print $ENV{greenMsg};
exit $am_states{AM_STATE_GREEN};

# Copyright (c) 2003 Sun Microsystems, Inc. All  Rights Reserved.
# 
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions are met:
# 
# -Redistribution of source code must retain the above copyright notice, 
# this list of conditions and the following disclaimer.
# 
# -Redistribution in binary form must reproduce the above copyright notice, 
# this list of conditions and the following disclaimer in the documentation  
# and/or other materials provided with the distribution.
# 
# Neither the name of Sun Microsystems, Inc. or the names of contributors may 
# be used to endorse or promote products derived from this software without 
# specific prior written permission.
# 
# This software is provided "AS IS," without a warranty of any kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED. SUN MICROSYSTEMS, INC. ("SUN") AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
# 
# You acknowledge that  this software is not designed or intended for use in the design, construction, operation or maintenance of any nuclear facility.
